Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1505)

Unified Diff: chrome/browser/ui/views/payments/payment_request_views_util.h

Issue 2896263002: [Payments] Changes to validation in the Credit Card editor (Closed)
Patch Set: rebase Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/payments/payment_request_views_util.h
diff --git a/chrome/browser/ui/views/payments/payment_request_views_util.h b/chrome/browser/ui/views/payments/payment_request_views_util.h
index ef9cadf10682634e1a6b0a9d404e67807a2cb3b0..9efedc2351fcff4df03649bf783a532a181c27a4 100644
--- a/chrome/browser/ui/views/payments/payment_request_views_util.h
+++ b/chrome/browser/ui/views/payments/payment_request_views_util.h
@@ -71,12 +71,13 @@ std::unique_ptr<views::View> CreateSheetHeaderView(
const base::string16& title,
views::ButtonListener* delegate);
// Returns an instrument image view for the given |icon_resource_id|. Includes
// a rounded rect border. Callers need to set the size of the resulting
// ImageView. Callers should set a |tooltip_text|.
std::unique_ptr<views::ImageView> CreateInstrumentIconView(
int icon_resource_id,
- const base::string16& tooltip_text);
+ const base::string16& tooltip_text,
+ float opacity = 1.0f);
std::unique_ptr<views::View> CreateProductLogoFooterView();

Powered by Google App Engine
@@ -71,12 +71,13 @@ std::unique_ptr<views::View> CreateSheetHeaderView(
const base::string16& title,
views::ButtonListener* delegate);
-// Returns an instrument image view for the given |icon_resource_id|. Includes
-// a rounded rect border. Callers need to set the size of the resulting
-// ImageView. Callers should set a |tooltip_text|.
+// Returns an instrument image view for the given |icon_resource_id| and wanted
+// |opacity|. Includes a rounded rect border. Callers need to set the size of
+// the resulting ImageView. Callers should set a |tooltip_text|.
std::unique_ptr<views::ImageView> CreateInstrumentIconView(
int icon_resource_id,
This is Rietveld 408576698